# Change logs

## 0.1 Changelog

### **unreleased**
 * Build Command Line Interface (``argparse`` or ``click``)


### **v0.0.1b2**
 * Game board is colored only in OS Linux

Released: Wed July 22 2020


### **0.0.1b1**

Released: Wed July 22 2020

 * Initial release.
